@@ -55,9 +55,9 @@
 #include <QMatrix4x4>
 #include <QOpenGLFunctions>
 #include <QOpenGLTexture>
+#include <QRandomGenerator>
 
 Window::Window()
-    : m_compositor(0)
 {
 }
 
@@ -70,11 +70,12 @@ void Window::initializeGL()
     m_textureBlitter.create();
 }
 
-static int sillyrandom(int range)
+static QPoint sillyrandom(int seed, QSize screenSize, QSize surfaceSize)
 {
-    if (range <= 0)
-        range = 200;
-    return qrand() % range;
+    QRandomGenerator rand(seed);
+    int xrange = qMax(screenSize.width() - surfaceSize.width(), 200);
+    int yrange = qMax(screenSize.height() - surfaceSize.height(), 200);
+    return QPoint(rand.bounded(xrange), rand.bounded(yrange));
 }
 
 void Window::paintGL()
@@ -90,11 +91,7 @@ void Window::paintGL()
     functions->glEnable(GL_BLEND);
     functions->glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
 
-    qsrand(31337);
-
     Q_FOREACH (View *view, m_compositor->views()) {
-        if (view->isCursor())
-            continue;
         auto texture = view->getTexture();
         if (!texture)
             continue;
@@ -106,7 +103,7 @@ void Window::paintGL()
         QWaylandSurface *surface = view->surface();
         if (surface && surface->hasContent()) {
             QSize s = surface->size();
-            QPointF pos(sillyrandom(width() - s.width()), sillyrandom(height() - s.height()));
+            QPointF pos = sillyrandom(view->iviId(), size(), s);
             QRectF surfaceGeometry(pos, s);
             QOpenGLTextureBlitter::Origin surfaceOrigin =
                     view->currentBuffer().origin() == QWaylandSurface::OriginTopLeft
